tdub.hist
---------

A module for histogramming

.. currentmodule:: tdub.hist

Function Summary
^^^^^^^^^^^^^^^^

.. autosummary::

   arrays_to_th1
   bin_centers
   edges_and_centers
   generate_from_df
   df_to_th1
   prepare_padded
   to_uniform_bins

Reference
^^^^^^^^^

.. autofunction:: arrays_to_th1
.. autofunction:: bin_centers
.. autofunction:: edges_and_centers
.. autofunction:: generate_from_df
.. autofunction:: df_to_th1
.. autofunction:: prepare_padded
.. autofunction:: to_uniform_bins
